RangeAllocationError

Struct RangeAllocationError 

pub struct RangeAllocationError<T> {
    pub fragmented_free_length: T,
}
The error returned when an allocation cannot be satisfied.

Contains the total free space that is available but fragmented across non-contiguous ranges.

Fields

fragmented_free_length: T

The total length of all free ranges combined. When this is greater than or equal to the requested length, the allocation failed due to fragmentation rather than insufficient space.